@@ -4,8 +4,6 @@ Ranking Metrics
 ==============
     Metrics to evaluate ranking quality of ranker models.
 """
-from typing import Tuple
-
 import torch
 
 from pytorch_lightning.metrics import Metric
@@ -17,14 +15,13 @@ class WMTKendall(Metric):
 
     def forward(
         self, distance_pos: torch.Tensor, distance_neg: torch.Tensor
-    ) -> Tuple[torch.Tensor]:
+    ) -> torch.Tensor:
         """Computes the level of concordance, discordance and the WMT kendall tau metric
 
-        :param distance_pos: distance between the positive samples and the anchor (aka reference)
-        :param distance_neg: distance between the negative samples and the anchor (aka reference)
+        :param distance_pos: distance between the positive samples and the anchor/s 
+        :param distance_neg: distance between the negative samples and the anchor/s
 
-        :return: Tuple(Level of agreement, nº of positive sample closer to the anchor, 
-            nº of negative sample closer to the anchor).
+        :return: Level of agreement, nº of positive sample closer to the anchor
         """
         concordance = torch.sum((distance_pos < distance_neg).float())
         discordance = torch.sum((distance_pos >= distance_neg).float())
