@@ -8,16 +8,14 @@ from comet.metrics import RegressionReport, WMTKendall
 
 
 class TestMetrics(unittest.TestCase):
-
-    
     def test_regression_report(self):
         report = RegressionReport()
         a = np.array([0, 0, 0, 1, 1, 1, 1])
         b = np.arange(7)
         expected = {
-            "pearson": torch.tensor(0.8660254, dtype=torch.float32), 
-            "kendall": torch.tensor(0.7559289, dtype=torch.float32), 
-            "spearman": torch.tensor(0.866025, dtype=torch.float32)
+            "pearson": torch.tensor(0.8660254, dtype=torch.float32),
+            "kendall": torch.tensor(0.7559289, dtype=torch.float32),
+            "spearman": torch.tensor(0.866025, dtype=torch.float32),
         }
         result = report(a, b)
         self.assertDictEqual(
@@ -32,5 +30,5 @@ class TestMetrics(unittest.TestCase):
         neg = torch.tensor([1, 0.5, 0])
 
         expected = (1 - 2) / (1 + 2)
-        
+
         self.assertEqual(metric(pos, neg), expected)
